# lightNLP
自然语言处理相关模型、数据和自己的笔记理解。

## 自然语言处理四大类任务

- 序列标注：分词/POS Tag/NER/语义标注……
- 分类任务：文本分类/情感计算……
- 句子关系判断：Enatailment/QA/自然语言推理……
- 生成式任务：机器翻译/文本摘要……

## 打算放入的内容

- 基于符号的自然语言处理
- 基于统计的自然语言处理
- 词向量
- 文本分类
- 序列标注
- 情感分析
- 命名实体类别
- 属性抽取
- 关系抽取
- 事件抽取
- 关键词抽取
- 条件随机场
- 支持向量机
- 中文分词

等等。

## 参考
- [从Word Embedding到Bert模型—自然语言处理中的预训练技术发展史](https://zhuanlan.zhihu.com/p/49271699)
